{ config, pkgs, ... }:

let
  choose-pass =
    pkgs.callPackage ./macos/choose-pass.nix { inherit config pkgs; };
in {
  nix.extraOptions = ''
    experimental-features = nix-command flakes
  '';

  # nixpkgs.config.permittedInsecurePackages = [ "python-2.7.18.6" ];

  # List packages installed in system profile. To search by name, run:
  # $ nix-env -qaP | grep wget
  # environment.systemPackages = [ ];
  environment.systemPackages = [
    (pkgs.pass.withExtensions (exts: [ exts.pass-otp ]))
    choose-pass
    # pkgs.khal
    pkgs.alacritty
    pkgs.gopass
    pkgs.ansible
    pkgs.bat
    pkgs.black
    pkgs.cheat
    pkgs.cmatrix
    pkgs.colima
    pkgs.coreutils-full
    pkgs.csvkit
    pkgs.curl
    pkgs.diff-so-fancy
    pkgs.docker-client
    pkgs.docker-machine
    pkgs.exa
    pkgs.fzf
    pkgs.getopt
    pkgs.gnupg
    pkgs.go
    pkgs.google-cloud-sdk
    pkgs.gping
    pkgs.hlint
    pkgs.htop
    pkgs.imagemagick
    pkgs.jq
    pkgs.khard
    pkgs.libmysqlclient.dev
    pkgs.mosh
    pkgs.mpc-cli
    pkgs.ncmpcpp
    pkgs.neofetch
    pkgs.neomutt
    pkgs.newsboat
    pkgs.nixfmt
    pkgs.nodePackages.pyright
    pkgs.python310Packages.python-lsp-server
    # pkgs.python310Packages.pylsp-mypy
    pkgs.openssh
    pkgs.pinentry_mac
    pkgs.pipenv
    pkgs.python310Full
    pkgs.python310Packages.pip
    pkgs.python310Packages.virtualenvwrapper
    # pkgs.pythonFull
    pkgs.ripgrep
    pkgs.shellcheck
    pkgs.shfmt
    pkgs.sqlfluff
    pkgs.starship
    pkgs.stow
    pkgs.terraform
    pkgs.tmux
    pkgs.tree
    pkgs.urlscan
    pkgs.vagrant
    pkgs.vdirsyncer
    pkgs.virtualenv
    pkgs.wget
    pkgs.wireguard-go
    pkgs.wireguard-tools
    pkgs.yubikey-personalization
    pkgs.zsh
  ];
  # Use a custom configuration.nix location.
  # $ darwin-rebuild switch -I darwin-config=$HOME/.config/nixpkgs/darwin/configuration.nix
  environment.darwinConfig = "/Users/rilla/configs/nix-config/echidna.nix";
  # environment.variables.DOCKER_HOST = "tcp://localhost:2375";

  # Auto upgrade nix package and the daemon service.
  services.nix-daemon.enable = true;
  # nix.package = pkgs.nix;

  # Create /etc/bashrc that loads the nix-darwin environment.
  programs.zsh.enable = true; # default shell on catalina
  # programs.fish.enable = true;

  # Used for backwards compatibility, please read the changelog before changing.
  # $ darwin-rebuild changelog

  programs.gnupg.agent = {
    enable = true;
    enableSSHSupport = true;
  };

  homebrew = {
    enable = true;
    onActivation = {
      cleanup = "zap";
      autoUpdate = true;
      upgrade = true;
    };
    global = {
      brewfile = true;
      lockfiles = true;
    };
    casks = [ "kmbmpdc" "librewolf" "virtualbox" "bluetility" ];
    brews = [
      "pyenv"
      "pyenv-virtualenv"
      "mpd"
      "choose-gui"
      "vitetris"
      "yabai"
      "skhd"
      "spacebar"
      "gnu-getopt"
      "coreutils"
      "pinentry-mac"
    ];
    taps = [
      "homebrew/bundle"
      "homebrew/cask"
      "homebrew/core"
      "homebrew/services"
      "koekeishiya/formulae"
      "cmacrae/formulae"
    ];
  };

  fonts = {
    fontDir.enable = true;
    fonts = [
      (pkgs.nerdfonts.override { fonts = [ "Hack" "MPlus" ]; })
      pkgs.inter
      pkgs.hack-font
      pkgs.libertinus
    ];
  };

  users.users.rilla = {
    name = "rilla";
    home = "/Users/rilla";
  };

  home-manager = { users.rilla.imports = [ home/echidna.nix ]; };

  system.stateVersion = 4;
}
