{ config, pkgs, ... }:

let
  obtoxmd = pkgs.callPackage ./obtoxmd.nix { inherit config pkgs; };
in {
  imports = [ ./rofi.nix ./misc.nix ];
  home = {
    keyboard = {
      layout = "us";
      options = [ "caps:escape" ];
      variant = "altgr-intl";
    };
    packages = [ obtoxmd pkgs.openbox pkgs.xsel ];
    file = {
      ".xmonad/icons/3cols.xpm".source = ./icons/3cols.xpm;
      ".xmonad/icons/float.xpm".source = ./icons/float.xpm;
      ".xmonad/icons/full.xpm".source = ./icons/full.xpm;
      ".xmonad/icons/grid.xpm".source = ./icons/grid.xpm;
      ".xmonad/icons/mtall.xpm".source = ./icons/mtall.xpm;
      ".xmonad/icons/tabs.xpm".source = ./icons/tabs.xpm;
      ".xmonad/icons/tall.xpm".source = ./icons/tall.xpm;
    };
  };

  xsession = {
    enable = true;
    initExtra = ''
      xset s off -dpms
      ${pkgs.autorandr}/bin/autorandr --change --default default
      export WINIT_X11_SCALE_FACTOR=1.33
    '';
  };

  services.stalonetray = {
    enable = true;
    config = {
      icon_size = 16;
      background = "#282828";  # todo
      sticky = true;
      geometry = "3x1-350+0";
      icon_gravity = "E";
      grow_gravity = "E";
    };
  };

  programs.zsh.loginExtra = ''
    [[ -z "''${DISPLAY}" ]] && [[ "$(tty)" = "/dev/tty1" ]] && \
        exec "${pkgs.xorg.xinit}/bin/startx" 1> "${config.home.homeDirectory}/.xsession-errors" 2>&1
  '';

}
