{ config, pkgs, ... }:

let
  url = "nextcloud.monotremata.xyz";
  dir = "${config.home.homeDirectory}/.newsboat";
  user = "rilla";
  rsssync = pkgs.callPackage ./rsssync.nix { inherit config pkgs; };
in
{
  home.packages = [rsssync];
  programs.newsboat = {
    enable = true;
    autoReload = true;
    browser = "firefox";  # todo: should be my open_link script
    reloadThreads = 100;
    extraConfig = ''
      urls-source "ocnews"
      ocnews-url "https://${url}/"
      ocnews-login "${user}"
      ocnews-passwordeval "${pkgs.pass}/bin/pass narwhal/${url}/${user}"

      # unbind keys
      unbind-key j
      unbind-key k
      unbind-key J
      unbind-key K

      # bind keys - vim style
      bind-key j down
      bind-key k up
      bind-key l open
      bind-key h quit

      color background          color15   color0
      color listnormal          color15   color0
      color listfocus           color230  color4
      color listnormal_unread   color2    color0
      color listfocus_unread    color2    color4  bold
      color info                color230  color4  bold
      color article             color15   color0

      cache-file ${dir}/cache.db
      cookie-cache ${dir}/cookies.txt
      error-log ${dir}/error.log
      save-path ${config.home.homeDirectory}/Documents/Articles"
    '';
  };
}
